Cheshire3 Object Model - DocumentFactory
========================================

.. _objects-documentFactory-api:

API
---

.. autoclass:: cheshire3.baseObjects.DocumentFactory
   :members:


.. _objects-documentFactory-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.documentFactory.SimpleDocumentFactory

.. autoclass:: cheshire3.documentFactory.ClusterExtractionDocumentFactory
